==> odata-client-microsoft-dynamics-0.1.45-sources.jar: microsoft/dynamics/crm/complex/RetrieveTimelineWallRecordsResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "TimelineWallRecords"})
@JsonInclude(Include.NON_NULL)
public class RetrieveTimelineWallRecordsResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("TimelineWallRecords")
    protected String timelineWallRecords;

    protected RetrieveTimelineWallRecordsResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RetrieveTimelineWallRecordsResponse";
    }

    @Property(name="TimelineWallRecords")
    @JsonIgnore
    public Optional<String> getTimelineWallRecords() {
        return Optional.ofNullable(timelineWallRecords);
    }

    public RetrieveTimelineWallRecordsResponse withTimelineWallRecords(String timelineWallRecords) {
        Checks.checkIsAscii(timelineWallRecords);
        RetrieveTimelineWallRecordsResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RetrieveTimelineWallRecordsResponse");
        _x.timelineWallRecords = timelineWallRecords;
        return _x;
    }

    public RetrieveTimelineWallRecordsResponse withUnmappedField(String name, String value) {
        RetrieveTimelineWallRecordsResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String timelineWallRecords;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder timelineWallRecords(String timelineWallRecords) {
            this.timelineWallRecords = timelineWallRecords;
            this.changedFields = changedFields.add("TimelineWallRecords");
            return this;
        }

        public RetrieveTimelineWallRecordsResponse build() {
            RetrieveTimelineWallRecordsResponse _x = new RetrieveTimelineWallRecordsResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RetrieveTimelineWallRecordsResponse";
            _x.timelineWallRecords = timelineWallRecords;
            return _x;
        }
    }

    private RetrieveTimelineWallRecordsResponse _copy() {
        RetrieveTimelineWallRecordsResponse _x = new RetrieveTimelineWallRecordsResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.timelineWallRecords = timelineWallRecords;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RetrieveTimelineWallRecordsResponse[");
        b.append("TimelineWallRecords=");
        b.append(this.timelineWallRecords);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.1.69.1-sources.jar: microsoft/dynamics/crm/complex/RetrieveTimelineWallRecordsResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "TimelineWallRecords"})
@JsonInclude(Include.NON_NULL)
public class RetrieveTimelineWallRecordsResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("TimelineWallRecords")
    protected String timelineWallRecords;

    protected RetrieveTimelineWallRecordsResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RetrieveTimelineWallRecordsResponse";
    }

    @Property(name="TimelineWallRecords")
    @JsonIgnore
    public Optional<String> getTimelineWallRecords() {
        return Optional.ofNullable(timelineWallRecords);
    }

    public RetrieveTimelineWallRecordsResponse withTimelineWallRecords(String timelineWallRecords) {
        Checks.checkIsAscii(timelineWallRecords);
        RetrieveTimelineWallRecordsResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RetrieveTimelineWallRecordsResponse");
        _x.timelineWallRecords = timelineWallRecords;
        return _x;
    }

    public RetrieveTimelineWallRecordsResponse withUnmappedField(String name, String value) {
        RetrieveTimelineWallRecordsResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String timelineWallRecords;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder timelineWallRecords(String timelineWallRecords) {
            this.timelineWallRecords = timelineWallRecords;
            this.changedFields = changedFields.add("TimelineWallRecords");
            return this;
        }

        public RetrieveTimelineWallRecordsResponse build() {
            RetrieveTimelineWallRecordsResponse _x = new RetrieveTimelineWallRecordsResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RetrieveTimelineWallRecordsResponse";
            _x.timelineWallRecords = timelineWallRecords;
            return _x;
        }
    }

    private RetrieveTimelineWallRecordsResponse _copy() {
        RetrieveTimelineWallRecordsResponse _x = new RetrieveTimelineWallRecordsResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.timelineWallRecords = timelineWallRecords;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RetrieveTimelineWallRecordsResponse[");
        b.append("TimelineWallRecords=");
        b.append(this.timelineWallRecords);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
